=======================
 Invenio-Groups v0.1.1
=======================

Invenio-Groups v0.1.1 was released on August 4, 2015.

About
-----

Invenio module that adds support for user groups.

*This is an experimental development preview release.*

Bug fixes
---------

- Removes dependency on Invenio legacy package.

Installation
------------

   $ pip install invenio-groups==0.1.1

Documentation
-------------

   http://invenio-groups.readthedocs.org/en/v0.1.1

Happy hacking and thanks for flying Invenio-Groups.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-groups
|   URL: http://invenio-software.org
